/////////////////////////////////////////////////////////
// RimLight
// By Richard Lems
/////////////////////////////////////////////////////////


uniform mediump float s; // size
uniform mediump float d; // intensity
uniform mediump float angl; // angle in degrees
uniform lowp vec3 clr; // color

//The current foreground texture co-ordinate
varying mediump vec2 vTex;
//The foreground texture sampler, to be sampled at vTex
uniform lowp sampler2D samplerFront;
//The current foreground rectangle being rendered
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
//The current foreground source rectangle being rendered
uniform mediump vec2 srcOriginStart;
uniform mediump vec2 srcOriginEnd;
//The current foreground source rectangle being rendered, in layout 
uniform mediump vec2 layoutStart;
uniform mediump vec2 layoutEnd;
//The background texture sampler used for background - blending effects
uniform lowp sampler2D samplerBack;
//The current background rectangle being rendered to, in texture co-ordinates, for background-blending effects
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
//The time in seconds since the runtime started. This can be used for animated effects
uniform mediump float seconds;
//The size of a texel in the foreground texture in texture co-ordinates
uniform mediump vec2 pixelSize;
//The current layer scale as a factor (i.e. 1 is unscaled)
uniform mediump float layerScale;
//The current layer angle in radians.
uniform mediump float layerAngle;

void main(void)
{	
  // we input in degrees for ease of use, but needs to be converted to radians
    mediump float angle = angl * 3.14159265359 / 180.0;
    
    // multiply the intensity value with the pixel size uniform
	mediump vec2 size = pixelSize * s;
	
	// calculate the outline value using the sprite texture and angle uniform
	mediump float outline = texture2D(samplerFront, vTex + vec2(size.x * cos(angle), size.y * sin(angle) )).a;
	
	// "invert"
	outline = 1.0 - outline;
	
	// get sprite texture
	mediump vec4 color = texture2D(samplerFront, vTex);
	
	// clip to sprite alpha
	mediump float rim = outline * color.a * d;
	
	// add everything together
	gl_FragColor = texture2D(samplerFront, vTex) + vec4(rim * clr.r, rim * clr.g, rim * clr.b, 0);
}